/*
 * File:   IO_Functions.c
 * Author: rmcnamee
 *
 * Created on December 7, 2017, 8:53 AM
 */

#include "mcc_generated_files/pin_manager.h"
#include "IO_Functions.h"


// Provides any setup needed for IO
void SetupIo(void)
{    
}

// Sets CTS low, allowing the MCP2200 to send all buffered responses to the host
void SetCtsLowForSerialSend(void)
{
    USB_CTS_SetLow();
}

// Sets CTS high, so the MCP2200 will not send any responses to the host
void SetCtsHighForSerialSendComplete(void)
{
    USB_CTS_SetHigh();
}

// Active low. Enables the Flash memory chip select for SPI
void EnableFlashChipSelect(void)
{
    FLASH_CS_SetLow();
}

// Active low. Disables the Flash memory chip select for SPI
void DisableFlashChipSelect(void)
{
    FLASH_CS_SetHigh();
}

// Active low. Disables write protect on the flash memory
void DisableFlashWriteProtect(void)
{
    FLASH_WP_SetLow();
}

// Active low. Enables write protect on the flash memory
void EnableFlashWriteProtect(void)
{
    FLASH_WP_SetHigh();
}

// Enables power to the switches
void EnablePowerToSwitches(void)
{
    SWITCH_POWER_ENABLE_SetHigh();
}

// Disables power to the switches
void DisablePowerToSwitches(void)
{
    SWITCH_POWER_ENABLE_SetLow();
}

// Active low. Selects switch 1 SPI chip select
void EnableSwitch1ChipSelect(void)
{
    SWITCH1_SS_SetLow();
}

// Active low. De-selects switch 1 SPI chip select
void DisableSwitch1ChipSelect(void)
{
    SWITCH1_SS_SetHigh();
}

// Active low. Selects switch 2 SPI chip select
void EnableSwitch2ChipSelect(void)
{
    SWITCH2_SS_SetLow();
}

// Active low. De-selects switch 2 SPI chip select
void DisableSwitch2ChipSelect(void)
{
    SWITCH2_SS_SetHigh();
}

// Active low. Selects switch 2 SPI chip select
void EnableRockerChipSelect(void)
{
    ROCKER_SS_SetLow();
}

// Active low. De-selects switch 2 SPI chip select
void DisableRockerChipSelect(void)
{
    ROCKER_SS_SetHigh();
}

// Sets the Data/Command line low, which enables commands and disables image data
void EnableSwitchCommandSending(void)
{
    OLED_DATA_OR_COMMAND_SetLow();
}

// Sets the Data/Command line high, which disables commands and enables image data
void DisableSwitchCommandSending(void)
{
    OLED_DATA_OR_COMMAND_SetHigh();
}

// Active low. Puts all switches in reset mode
void EnableSwitchReset(void)
{
    SWITCHES_RESET_SetLow();
    ROCKER_RESET_SetLow();
}

// Active low. Takes all switches out of reset mode
void DisableSwitchReset(void)
{
    SWITCHES_RESET_SetHigh();
    ROCKER_RESET_SetHigh();
}

void SetTestPin(bool state)
{
    if (state == true)
    {
        AUXILIARY_PIN2_SetHigh();
    }
    else
    {
        AUXILIARY_PIN2_SetLow();
    }
}

// Active low. Checks if switch 1 has been pressed
// Returns true if it has been pressed, false otherwise
bool CheckIfSwitch1Pressed(void)
{
    if (SWITCH1_OUTPUT_GetValue() == 0)
    {
        return true;
    }
    
    return false;
}

// Active low. Checks if switch 2 has been pressed.
// Returns true if it has been pressed, false otherwise
bool CheckIfSwitch2Pressed(void)
{
    if (SWITCH2_OUTPUT_GetValue() == 0)
    {
        return true;
    }
    
    return false;
}

// Active low. Checks if the rocker switch has been pressed.
// Returns the switch that was pressed. Gives middle priority
rockerPressEnum CheckIfRockerPressed(void)
{
    if (ROCKER_SW2_OUTPUT_GetValue() == 0)
    {
        return ROCKER_MIDDLE_PRESSED;
    }
    
    if (ROCKER_SW1_OUTPUT_GetValue() == 0)
    {
        return ROCKER_BOTTOM_PRESSED;
    }        
    
    if (ROCKER_SW3_OUTPUT_GetValue() == 0)
    {
        return ROCKER_TOP_PRESSED;
    }
    
    return ROCKER_NONE_PRESSED;
}